# Citations

## Citing Oumi

If you find Oumi useful in your research, please consider citing it using the following entry:

```bibtex
@software{oumi2025,
  author = {Oumi Community},
  title = {Oumi: an Open, End-to-end Platform for Building Large Foundation Models},
  month = {January},
  year = {2025},
  url = {https://github.com/oumi-ai/oumi}
}
```

## References

:::{bibliography}
:cited:
:notcited:
:::
